@@ -1,6 +1,5 @@
 from pdfrow import PDFRow
 from pdfcolumn import PDFColumn
-from pdfcell import PDFCell
 
 
 class PDFTable(object):
@@ -24,7 +23,6 @@ class PDFTable(object):
         for x in range(self.number_of_columns):
             self.columns.append(PDFColumn(parent=self))
 
-
         for x in range(self.number_of_rows):
             self.rows.append(PDFRow(self, x, self.number_of_columns,
                                     self.text_cursor, self.border_cursor))
@@ -104,7 +102,7 @@ class PDFTable(object):
             self.rows[i]._draw_fill()
 
     def _set_final_cursor(self):
-        if self.text_cursor > (self.border_cursor):
+        if self.text_cursor > self.border_cursor:
             self.cursor = self.text_cursor
         else:
             self.cursor = self.border_cursor
